"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const fs_1 = require("../lib/utils/fs");
const util_1 = require("../lib/utils/util");
class DiffEnvNameType extends core_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = yield this.parse(DiffEnvNameType);
            const prev = (0, util_1.parseEnv)(flags['prev-env']);
            const after = (0, util_1.parseEnv)(flags['after-env']);
            const envNames = {};
            for (const [k] of Object.entries(after)) {
                // only print changed vars
                if (prev[k] !== after[k]) {
                    envNames[k] = k;
                }
            }
            const fileContent = `export const AllProjectDiffEnvNames = ${JSON.stringify(envNames, null, 2)} as const;
export type ProjectDiffEnvName = keyof typeof AllProjectDiffEnvNames;`;
            if (flags.output) {
                (0, fs_1.outputFile)(flags.output, fileContent);
            }
            else {
                console.log(fileContent);
            }
        });
    }
}
exports.default = DiffEnvNameType;
DiffEnvNameType.description = 'Output diff env name type definition';
DiffEnvNameType.examples = [
    `$ typed-env diff-env-name-type -p "$(prev_env)" -a "$(env)" -o ./src/env.d.ts`,
];
DiffEnvNameType.flags = {
    'prev-env': core_1.Flags.string({
        char: 'p',
        description: 'enter current env',
        required: true,
    }),
    'after-env': core_1.Flags.string({
        char: 'a',
        description: 'enter change env',
        required: true,
    }),
    output: core_1.Flags.string({
        char: 'o',
        description: 'enter the output file path',
    }),
};
