"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const fs_1 = require("../lib/utils/fs");
const generate_env_1 = require("../lib/generate-env");
class GenEnvNameType extends core_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = yield this.parse(GenEnvNameType);
            const envNames = (0, generate_env_1.generateEnvName)({
                sourceFilePath: flags['source-file'],
                options: { tsConfigFilePath: flags.tsconfig },
            });
            const fileContent = `export const AllProjectEnvNames = ${JSON.stringify(envNames, null, 2)} as const;
export type ProjectEnvName = keyof typeof AllProjectEnvNames;`;
            if (flags.output) {
                (0, fs_1.outputFile)(flags.output, fileContent);
            }
            else {
                console.log(fileContent);
            }
        });
    }
}
exports.default = GenEnvNameType;
GenEnvNameType.description = 'Generate env name type definition';
GenEnvNameType.examples = [
    `$ typed-env gen-env-name-type -s ./src/index.ts -t ./tsconfig.json -o ./src/env.d.ts`,
];
GenEnvNameType.flags = {
    'source-file': core_1.Flags.string({
        char: 's',
        description: 'enter the file path(.ts) to check',
        required: true,
    }),
    tsconfig: core_1.Flags.string({
        char: 't',
        description: 'enter the tsconfig.json path',
        required: true,
    }),
    output: core_1.Flags.string({
        char: 'o',
        description: 'enter the output file path',
    }),
};
