"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const fs_1 = require("../lib/utils/fs");
const generate_env_1 = require("../lib/generate-env");
class GenEnv extends core_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = yield this.parse(GenEnv);
            const info = (0, generate_env_1.generateEnv)({
                sourceFilePath: flags['source-file'],
                options: { tsConfigFilePath: flags.tsconfig },
            });
            if (flags.output) {
                (0, fs_1.outputFile)(flags.output, info.join('\n'));
            }
            else {
                console.log(info);
            }
        });
    }
}
exports.default = GenEnv;
GenEnv.description = 'Generate .env';
GenEnv.examples = [
    `$ typed-env gen-env -s ./src/index.ts -t ./tsconfig.json -o ./src/.env`,
];
GenEnv.flags = {
    'source-file': core_1.Flags.string({
        char: 's',
        description: 'enter the file path(.ts) to check',
        required: true,
    }),
    tsconfig: core_1.Flags.string({
        char: 't',
        description: 'enter the tsconfig.json path',
        required: true,
    }),
    output: core_1.Flags.string({
        char: 'o',
        description: 'enter the output file path',
    }),
};
